CRYPTO_tls1_prf

Function CRYPTO_tls1_prf 

pub unsafe extern "C" fn CRYPTO_tls1_prf(
    digest: *const EVP_MD,
    out: *mut u8,
    out_len: usize,
    secret: *const u8,
    secret_len: usize,
    label: *const u8,
    label_len: usize,
    seed1: *const u8,
    seed1_len: usize,
    seed2: *const u8,
    seed2_len: usize,
) -> c_int
Calculates out_len bytes of the TLS 1.2 PRF using digest and writes them to out.

This symbol is exported by BoringSSL, but it is declared in an internal header (crypto/fipsmodule/tls/internal.h) and is therefore not present in generated bindgen output.